@@ -14,15 +14,18 @@ module Puppet::Provider::Mount
         if self.options and self.options != :absent
             args << "-o" << self.options
         end
-        args << @resource[:name]
+        args << resource[:name]
 
+        if respond_to?(:flush)
+            flush
+        end
         mountcmd(*args)
     end
 
     def remount
         info "Remounting"
-        if @resource[:remounts] == :true
-            mountcmd "-o", "remount", @resource[:name]
+        if resource[:remounts] == :true
+            mountcmd "-o", "remount", resource[:name]
         else
             unmount()
             mount()
@@ -31,27 +34,22 @@ module Puppet::Provider::Mount
 
     # This only works when the mount point is synced to the fstab.
     def unmount
-        umount @resource[:name]
+        umount resource[:name]
     end
 
     # Is the mount currently mounted?
     def mounted?
-        platform = Facter["operatingsystem"].value
-        df = [command(:df)]
-        case Facter["operatingsystem"].value
-        # Solaris's df prints in a very weird format
-        when "Solaris": df << "-k"
-        end
-        execute(df).split("\n").find do |line|
-            fs = line.split(/\s+/)[-1]
-            if platform == "Darwin"
-                fs == "/private/var/automount" + @resource[:name] or
-                    fs == @resource[:name]
+        platform = Facter.value("operatingsystem")
+        name = resource[:name]
+        mounts = mountcmd.split("\n").find do |line|
+            case platform
+            when "Darwin"
+                line =~ / on #{name} / or line =~ %r{ on /private/var/automount#{name}}
+            when "Solaris"
+                line =~ /^#{name} on /
             else
-                fs == @resource[:name]
+                line =~ / on #{name} /
             end
         end
     end
 end
-
-# $Id: mount.rb 2501 2007-05-09 23:08:42Z luke $
