@@ -1,6 +1,6 @@
 #!/usr/bin/env ruby
 
-$:.unshift("../lib") if __FILE__ =~ /\.rb$/
+require File.dirname(__FILE__) + '/../lib/puppettest'
 
 require 'puppettest'
 
@@ -35,5 +35,4 @@ class TestClientRequest < Test::Unit::TestCase
     end
 end
 
-# $Id: client_request.rb 2259 2007-03-06 19:03:05Z luke $
 
